@@ -2,11 +2,11 @@
 
 cart-review checkout
 
-$Id: checkout.py 2128 2008-11-16 20:15:19Z horacio.duran $
+$Id: checkout.py 2163 2008-12-30 22:05:21Z lucielejard $
 """
 
 
-import decimal,operator
+import operator
 import cgi
 from cPickle import loads, dumps
 from datetime import timedelta
@@ -24,7 +24,7 @@ from zope.app.apidoc import interface as apidocInterface
 
 from zc.table import column
 from getpaid.wizard import Wizard, ListViewController, interfaces as wizard_interfaces
-from getpaid.core import interfaces, options, payment, cart
+from getpaid.core import interfaces, options, cart
 from getpaid.core.order import Order
 
 import Acquisition
@@ -34,7 +34,7 @@ from ZTUtils.Zope import complex_marshal
 
 from Products.Five.formlib import formbase
 from Products.Five.browser import BrowserView
-from Products.Five.browser.pagetemplatefile import ZopeTwoPageTemplateFile,ViewPageTemplateFile
+from Products.Five.browser.pagetemplatefile import ZopeTwoPageTemplateFile
 from Products.CMFCore.utils import getToolByName
 
 # Bruno - missing import for INamedOrderUtility
@@ -42,7 +42,7 @@ from Products.PloneGetPaid.interfaces import INamedOrderUtility
 
 from Products.PloneGetPaid.interfaces import IGetPaidManagementOptions, IAddressBookUtility
 from Products.PloneGetPaid.i18n import _
-
+from Products.PloneGetPaid import config
 
 from base import BaseFormView
 import cart as cart_core
@@ -171,7 +171,6 @@ class BaseCheckoutForm( BaseFormView ):
 
     def createTransientOrder( self ):
         order = Order()
-
         shopping_cart = component.getUtility( interfaces.IShoppingCartUtility ).get( self.context )
         formSchemas = component.getUtility(interfaces.IFormSchemas)
 
@@ -660,6 +659,7 @@ class CheckoutReviewAndPay( BaseCheckoutForm ):
             order.shipping_service = shipping_service
             order.shipping_method = shipping_method
             order.shipping_cost = shipping_method_obj.cost
+            order.shipments = {} # XXX not implemented
 
         notify( ObjectCreatedEvent( order ) )
 
@@ -682,6 +682,12 @@ class CheckoutReviewAndPay( BaseCheckoutForm ):
                      f_states.REVIEWING,
                      f_states.CHARGED):
             return base_url + '/@@getpaid-thank-you?order_id=%s&finance_state=%s' %(order.order_id, state)
+            
+    def isPlone3(self):
+        """test if it is a plone3 site
+        """
+        return config.PLONE3
+            
 
 class ShippingRate( options.PropertyBag ):
     title = "Shipping Rate"
